"use strict";

/* exported logger */

var ContextMenu = require('./ContextMenu');
var SubMenu = require('./SubMenu');
var Functions = require('../Functions');

var logger = require('../logger');

function SelectionContextMenu(params) {
  ContextMenu.call(this, params);
  var self = this;

  self._createSelectionContextMenuGui();
}

SelectionContextMenu.prototype = Object.create(ContextMenu.prototype);
SelectionContextMenu.prototype.constructor = SelectionContextMenu;

SelectionContextMenu.prototype.init = function() {
  var self = this;
  return ServerConnector.getImageConverters().then(function(converters){
    var li = Functions.createElement({
      type : "li"
    });
    var submenu = new SubMenu({
      element : li,
      name : "Export as image",
      customMap : self.getMap()
    });
    
    var map = self.getMap();
    converters.forEach(function(converter){
      submenu.addOption(converter.name, function(){
        return ServerConnector.getImageDownloadUrl({
          polygonString: map.getSelectedPolygon(),
          modelId: map.getActiveSubmapId(),
          handlerClass: converter.handler,
          backgroundOverlayId: map.getGoogleMap().getMapTypeId(),
          zoomLevel:map. getGoogleMap().getZoom(),
          overlayIds: map.getSelectedLayouts(),
        }).then(function(url){
          return self.downloadFile(url);
        }).catch(GuiConnector.alert);          
      });
      
    });
    self.addOption(submenu);
  });
};

SelectionContextMenu.prototype._createSelectionContextMenuGui = function() {
  var self = this;
  self.addOption("Remove Selection", function() {
    self.getMap().removeSelection();
    self.getMap().turnOnOffDrawing();
  });
};

module.exports = SelectionContextMenu;
